@@ -6,7 +6,7 @@ from .gpio import Chip
 from .libgpiod import *  # noqa
 
 
-def open_chip(num=0, consumer=sys.argv[0]):
+def open_chip(num=None, label=None, consumer=sys.argv[0]):
     """Returns an object representing a GPIO chip.
 
     Arguments:
@@ -18,4 +18,4 @@ def open_chip(num=0, consumer=sys.argv[0]):
     Returns:
         a :class:`asyncgpio.gpio.Chip` instance.
     """
-    return Chip(num, consumer=consumer)
+    return Chip(num=num, label=label, consumer=consumer)
